SummarizeOver: Grouping over a dimenension
==========================================

The SummarizeOver extension provides generates calculations over 
an aggregation of a Dimension.


.. module:: recipe

.. autoclass:: SummarizeOver
    :members: summarize_over
    :noindex:    

